==> rawtherapee_4.1.orig.tar.xz: rawtherapee-4.1/rtgui/addsetids.h <==
#ifndef _ADDSETIDS_
#define _ADDSETIDS_


//          UPDATE THE DEFAULT VALUE IN OPTIONS.CC  int babehav[] TOO !!!


#define ADDSET_TC_EXPCOMP               0
#define ADDSET_TC_BRIGHTNESS            1
#define ADDSET_TC_BLACKLEVEL            2
#define ADDSET_TC_CONTRAST              3
#define ADDSET_SH_HIGHLIGHTS            4
#define ADDSET_SH_SHADOWS               5
#define ADDSET_SH_LOCALCONTRAST         6
#define ADDSET_LC_BRIGHTNESS            7
#define ADDSET_LC_CONTRAST              8
#define ADDSET_SHARP_AMOUNT             9
#define ADDSET_WB_TEMPERATURE           10
#define ADDSET_WB_GREEN                 11
#define ADDSET_ROTATE_DEGREE            12
#define ADDSET_DIST_AMOUNT              13
#define ADDSET_PERSPECTIVE              14
#define ADDSET_CA                       15
#define ADDSET_VIGN_AMOUNT              16
#define ADDSET_VIGN_RADIUS              17
#define ADDSET_VIGN_STRENGTH            18
#define ADDSET_VIGN_CENTER              19
#define ADDSET_LC_CHROMATICITY          20
#define ADDSET_TC_SATURATION            21
#define ADDSET_TC_HLCOMPAMOUNT          22
#define ADDSET_TC_HLCOMPTHRESH          23
#define ADDSET_TC_SHCOMP                24
#define ADDSET_DIRPYREQ                 25
#define ADDSET_DIRPYRDN_LUMA            26
#define ADDSET_DIRPYRDN_LUMDET          27
#define ADDSET_DIRPYRDN_CHROMA          28
#define ADDSET_DIRPYRDN_CHROMARED       29
#define ADDSET_DIRPYRDN_CHROMABLUE      30
#define ADDSET_DIRPYRDN_GAMMA           31
#define ADDSET_CHMIXER                  32
#define ADDSET_PREPROCESS_GREENEQUIL    33
#define ADDSET_PREPROCESS_LINEDENOISE   34
#define ADDSET_RAWCACORR                35
#define ADDSET_RAWEXPOS_LINEAR          36
#define ADDSET_RAWEXPOS_PRESER          37
#define ADDSET_RAWEXPOS_BLACKS          38
#define ADDSET_SHARPENEDGE_AMOUNT       39
#define ADDSET_SHARPENMICRO_AMOUNT      40
#define ADDSET_SHARPENEDGE_PASS         41
#define ADDSET_SHARPENMICRO_UNIFORMITY  42
#define ADDSET_VIBRANCE_PASTELS         43
#define ADDSET_VIBRANCE_SATURATED       44
#define ADDSET_FREE_OUPUT_GAMMA         45
#define ADDSET_FREE_OUTPUT_SLOPE        46
#define ADDSET_CAT_DEGREE               47
#define ADDSET_CAT_ADAPTSCENE           48
#define ADDSET_CAT_ADAPTVIEWING         49
#define ADDSET_CAT_LIGHT                50
#define ADDSET_CAT_CHROMA               51
#define ADDSET_CAT_CONTRAST             52
#define ADDSET_CAT_RSTPRO               53
#define ADDSET_CAT_BRIGHT               54
#define ADDSET_CAT_CONTRAST_Q           55
#define ADDSET_CAT_CHROMA_S             56
#define ADDSET_CAT_CHROMA_M             57
#define ADDSET_CAT_HUE                  58
#define ADDSET_CAT_BADPIX               59
#define ADDSET_WB_EQUAL                 60
#define ADDSET_GRADIENT_DEGREE          61
#define ADDSET_GRADIENT_FEATHER         62
#define ADDSET_GRADIENT_STRENGTH        63
#define ADDSET_GRADIENT_CENTER          64
#define ADDSET_PCVIGNETTE_STRENGTH      65
#define ADDSET_PCVIGNETTE_FEATHER       66
#define ADDSET_PCVIGNETTE_ROUNDNESS     67
#define ADDSET_BLACKWHITE_HUES          68
#define ADDSET_BLACKWHITE_GAMMA         69
#define ADDSET_DIRPYREQ_THRESHOLD       70
#define ADDSET_DIRPYREQ_SKINPROTECT     71

// When adding items, make sure to update ADDSET_PARAM_NUM
#define ADDSET_PARAM_NUM                72 // THIS IS USED AS A DELIMITER!!

#endif

==> rawtherapee_4.2.orig.tar.xz: rawtherapee-4.2/rtgui/addsetids.h <==
#ifndef _ADDSETIDS_
#define _ADDSETIDS_


//          UPDATE THE DEFAULT VALUE IN OPTIONS.CC  int babehav[] TOO !!!


#define ADDSET_TC_EXPCOMP               0
#define ADDSET_TC_BRIGHTNESS            1
#define ADDSET_TC_BLACKLEVEL            2
#define ADDSET_TC_CONTRAST              3
#define ADDSET_SH_HIGHLIGHTS            4
#define ADDSET_SH_SHADOWS               5
#define ADDSET_SH_LOCALCONTRAST         6
#define ADDSET_LC_BRIGHTNESS            7
#define ADDSET_LC_CONTRAST              8
#define ADDSET_SHARP_AMOUNT             9
#define ADDSET_WB_TEMPERATURE           10
#define ADDSET_WB_GREEN                 11
#define ADDSET_ROTATE_DEGREE            12
#define ADDSET_DIST_AMOUNT              13
#define ADDSET_PERSPECTIVE              14
#define ADDSET_CA                       15
#define ADDSET_VIGN_AMOUNT              16
#define ADDSET_VIGN_RADIUS              17
#define ADDSET_VIGN_STRENGTH            18
#define ADDSET_VIGN_CENTER              19
#define ADDSET_LC_CHROMATICITY          20
#define ADDSET_TC_SATURATION            21
#define ADDSET_TC_HLCOMPAMOUNT          22
#define ADDSET_TC_HLCOMPTHRESH          23
#define ADDSET_TC_SHCOMP                24
#define ADDSET_DIRPYREQ                 25
#define ADDSET_DIRPYRDN_LUMA            26
#define ADDSET_DIRPYRDN_LUMDET          27
#define ADDSET_DIRPYRDN_CHROMA          28
#define ADDSET_DIRPYRDN_CHROMARED       29
#define ADDSET_DIRPYRDN_CHROMABLUE      30
#define ADDSET_DIRPYRDN_GAMMA           31
#define ADDSET_CHMIXER                  32
#define ADDSET_PREPROCESS_GREENEQUIL    33
#define ADDSET_PREPROCESS_LINEDENOISE   34
#define ADDSET_RAWCACORR                35
#define ADDSET_RAWEXPOS_LINEAR          36
#define ADDSET_RAWEXPOS_PRESER          37
#define ADDSET_RAWEXPOS_BLACKS          38
#define ADDSET_SHARPENEDGE_AMOUNT       39
#define ADDSET_SHARPENMICRO_AMOUNT      40
#define ADDSET_SHARPENEDGE_PASS         41
#define ADDSET_SHARPENMICRO_UNIFORMITY  42
#define ADDSET_VIBRANCE_PASTELS         43
#define ADDSET_VIBRANCE_SATURATED       44
#define ADDSET_FREE_OUPUT_GAMMA         45
#define ADDSET_FREE_OUTPUT_SLOPE        46
#define ADDSET_CAT_DEGREE               47
#define ADDSET_CAT_ADAPTSCENE           48
#define ADDSET_CAT_ADAPTVIEWING         49
#define ADDSET_CAT_LIGHT                50
#define ADDSET_CAT_CHROMA               51
#define ADDSET_CAT_CONTRAST             52
#define ADDSET_CAT_RSTPRO               53
#define ADDSET_CAT_BRIGHT               54
#define ADDSET_CAT_CONTRAST_Q           55
#define ADDSET_CAT_CHROMA_S             56
#define ADDSET_CAT_CHROMA_M             57
#define ADDSET_CAT_HUE                  58
#define ADDSET_CAT_BADPIX               59
#define ADDSET_WB_EQUAL                 60
#define ADDSET_GRADIENT_DEGREE          61
#define ADDSET_GRADIENT_FEATHER         62
#define ADDSET_GRADIENT_STRENGTH        63
#define ADDSET_GRADIENT_CENTER          64
#define ADDSET_PCVIGNETTE_STRENGTH      65
#define ADDSET_PCVIGNETTE_FEATHER       66
#define ADDSET_PCVIGNETTE_ROUNDNESS     67
#define ADDSET_BLACKWHITE_HUES          68
#define ADDSET_BLACKWHITE_GAMMA         69
#define ADDSET_DIRPYREQ_THRESHOLD       70
#define ADDSET_DIRPYREQ_SKINPROTECT     71
#define ADDSET_COLORTONING_SPLIT        72
#define ADDSET_COLORTONING_SATTHRESHOLD 73
#define ADDSET_COLORTONING_SATOPACITY   74
#define ADDSET_COLORTONING_BALANCE      75
#define ADDSET_COLORTONING_STRENGTH     76
#define ADDSET_DIRPYRDN_PASSES          77
#define ADDSET_RAWFFCLIPCONTROL         78
#define ADDSET_FILMSIMULATION_STRENGTH  79

// When adding items, make sure to update ADDSET_PARAM_NUM
#define ADDSET_PARAM_NUM                80 // THIS IS USED AS A DELIMITER!!

#endif
